@@ -5,7 +5,7 @@ append.in.focus<-function(X,focus.var,in.focus.var="in.focus"){
 	utf.db<-X[[,c(id.vars,focus.var)]]
 	names(utf.db)<-c(id.vars,"focus.var")
 	utf.db<-recast(utf.db,pos+t.frame+z.scan~variable,fun.aggregate=mean,id.var=id.vars)
-	utf.db<-transform.by(utf.db,.(pos,z.scan),in.focus=focus.var==max(focus.var))
+	utf.db<-transformBy(utf.db,.(pos,z.scan),in.focus=focus.var==max(focus.var))
 	names(utf.db)<-c(id.vars,focus.var,in.focus.var)
 	X=merge(X,subset(utf.db,select=c(id.vars,in.focus.var)),by=id.vars)
 	return(X)
@@ -135,6 +135,33 @@ append.memRec.y<-function(X){
   return(X)
 }
 
+append.memRec.r<-function(X){
+  on.exit(gc())
+  
+  cat("appending f.int.r \n")
+	X=transform(X,
+		f.int.r=
+	  ((f.tot.m3.r/a.tot.m3-f.local.bg.r)*(4/3)*pi*(-3+(maj.axis+min.axis)/4)^3) +
+	  ((f.m2.r/a.m2-f.local.bg.r)*4*pi*(-2+(maj.axis+min.axis)/4)^2) +
+	  ((f.m1.r/a.m1-f.local.bg.r)*4*pi*(-1+(maj.axis+min.axis)/4)^2) +
+	  ((f.m0.r/a.m0-f.local.bg.r)*4*pi*((maj.axis+min.axis)/4)^2) +
+	  ((f.p1.r/a.p1-f.local.bg.r)*4*pi*(+1+(maj.axis+min.axis)/4)^2)
+	)
+
+  cat("appending f.mem.r \n")
+	X=transform(X,
+	  f.mem.r=
+	  ((f.m0.r/a.m0-f.local.bg.r)*4*pi*((maj.axis+min.axis)/4)^2) +
+	  ((f.p1.r/a.p1-f.local.bg.r)*4*pi*(+1+(maj.axis+min.axis)/4)^2)
+	)
+  
+  cat("appending f.obs.r \n")
+	X=transform(X, f.obs.r= f.mem.r/f.int.r )
+
+  return(X)
+}
+
+
 append.oif.time<-function(X,OIF.date="OIF-date.txt",path=getwd(),pos.digits=2,oif.digits=2){
 	#loads times from a OIF-date.txt file, generated by the following scripts
 	#oif2txt.bat: for %%i in (*.oif) do type %%i > %%~ni.txt
@@ -154,7 +181,6 @@ append.oif.time<-function(X,OIF.date="OIF-date.txt",path=getwd(),pos.digits=2,oi
 	#to add seconds to a chron object
 	#SECONDS.PER.DAY=60*60*24
 	#oif.time+1/SECONDS.PER.DAY
-	#browser()
 
 	if(!"oif"%in%names(X$data)) 
 		stop("oif variable required in cell.data, run append.z.scan before calling this function",call.=FALSE)	
@@ -168,20 +194,23 @@ append.oif.time<-function(X,OIF.date="OIF-date.txt",path=getwd(),pos.digits=2,oi
 	oif.db=data.frame(
 		pos=as.numeric(substring(oif[oif.s,],1,pos.digits))
 		,oif=as.numeric(substring(oif[oif.s,],2+pos.digits,1+pos.digits+oif.digits))
-		,oif.hour=chron(times=substring(oif[oif.s+1,],32,40),format=c("h:m:s"))
+		,oif.hour=chron(times.=substring(oif[oif.s+1,],32,40),format=c("h:m:s"))
 		,oif.msec=as.numeric(substring(oif[oif.s+2,],30,nchar(oif[oif.s+2,])))
 	)
 	
-	#oif.db<-transform.by(oif.db,.(pos),oif.time=oif.hour-oif.hour[oif==1])
-
-	oif.db=transform.by(oif.db,.(pos)
+	#oif.db<-transformBy(oif.db,.(pos),oif.time=oif.hour-oif.hour[oif==1])
+	oif.db=transformBy(oif.db,.(pos)
 		,D.oif.hour=oif.hour-oif.hour[oif==1]
 		,D.oif.msec=oif.msec-oif.msec[oif==1])	
+
 	oif.db=transform(oif.db
 		,oif.time.s=3600*hours(D.oif.hour)+60*minutes(D.oif.hour)+seconds(D.oif.hour)+D.oif.msec/1000)
 
+	oif.db.table<-with(oif.db,table(pos,oif))
+	if(sum(oif.db.table>1)>0) 
+		stop("some pos has repeated oif in ",OIF.date)
 
-	tmp<-join(subset(X$data,select=c(pos,oif)),subset(oif.db,select=c(pos,oif,oif.time.s)),by=c("pos","oif"))
+	tmp<-join(X$data[,c("pos","oif")],subset(oif.db,select=c(pos,oif,oif.time.s)),by=c("pos","oif"))
 	tmp<-subset(tmp,select=c(-pos,-oif))
 	X$data<-cbind(X$data,tmp)
 	X$variables$merged<-union(X$variables$merged,names(tmp))
@@ -192,8 +221,6 @@ append.oif.time<-function(X,OIF.date="OIF-date.txt",path=getwd(),pos.digits=2,oi
 	return(X)
 }
 
-
-
 append.oif.interval<-function(X,OIF.interval="OIF-Interval.txt",path=getwd(),pos.digits=2,oif.digits=2){
 	#loads interval times from a OIF-Interval.txt file, generated by the following scripts
 	#oif2txt.bat: for %%i in (*.oif) do type %%i > %%~ni.txt
@@ -233,7 +260,6 @@ append.oif.interval<-function(X,OIF.interval="OIF-Interval.txt",path=getwd(),pos
 	return(X)
 }
 
-
 #removes usually unused variables
 CELLID_UNUSED_VARS=c("time","rot.vol","con.vol","a.tot.p1","a.tot.m1","a.tot.m2","a.tot.m3"
 					,"a.local.bg","a.local","a.local.bg2","a.local2","a.surf","sphere.vol"
