@@ -30,7 +30,7 @@ X<-QC.filter(X,fft.stat < 0.5) #apply the cut
 
 #filtering by the total number of frames in which a cell appears
 cplot(X,cellID~t.frame,fill=f.tot.y,geom="tile",facets=~pos) 
-X<-update.n.tot(X) #updating n.tot variable
+X<-update_n.tot(X) #updating n.tot variable
 cplot(X,~n.tot) #define where to apply the cut
 X<-QC.filter(X,n.tot==14) #keep cells that appear in all t.frames
 
@@ -97,7 +97,7 @@ flush(stderr()); flush(stdout())
 ### Name: append
 ### Title: Append Variables
 ### Aliases: append.in.focus append.z.scan append.anular.y append.anular.r
-###   append.anular.c append.memRec.y
+###   append.anular.c append.memRec.y append.memRec.r
 ### Keywords: manip
 
 ### ** Examples
@@ -188,14 +188,14 @@ df<-cdata(X,QC.filter=FALSE)
 
 
 cleanEx()
-nameEx("cell-counter")
-### * cell-counter
+nameEx("cell.counter")
+### * cell.counter
 
 flush(stderr()); flush(stdout())
 
-### Name: cell-counter
+### Name: cell.counter
 ### Title: Map Cell Counter Tags to Cells
-### Aliases: cell-counter cell.counter cardinality.plot map.cells.points
+### Aliases: cell.counter cardinality.plot map.cells.points
 ### Keywords: manip
 
 ### ** Examples
@@ -231,25 +231,27 @@ flush(stderr()); flush(stdout())
 
 ### ** Examples
 
-#load example dataset
-#warning: Any object named 'X' will be replaced
-data(ACL394filtered)
+  
+if(require(hopach,quietly=TRUE)){  #suggested package hopach required for this function
+  #load example dataset 
+  #warning: Any object named 'X' will be replaced
+  data(ACL394filtered)
 
-#Heriarchical clustering of cells by f.tot.y time course, 
-#using cosangle (uncentered correlation) metric and average linkage method.
-cell.hclust(X,"f.tot.y")
+  #Heriarchical clustering of cells by f.tot.y time course, 
+  #using cosangle (uncentered correlation) metric and average linkage method.
+  cell.hclust(X,"f.tot.y")
 
-#Heriarchical clustering of cells by f.tot.y time course, 
-#using euclid metric and complete linkage method.
-cell.hclust(X,"f.tot.y",metric="euclid",method="complete")
+  #Heriarchical clustering of cells by f.tot.y time course, 
+  #using euclid metric and complete linkage method.
+  cell.hclust(X,"f.tot.y",metric="euclid",method="complete")
 
-#Cut the tree at constant height and show the clusters
-cell.hclust(X,"f.tot.y",cutree="height",cutree.args=list(h=0.005))
-
-#redefining the formula, plot against time in minutes
-X<-transform(X,time.min=10+t.frame*15) #calculating the time of each t.frame
-cell.hclust(X,"f.tot.y",formula=ucid~variable+time.min)
+  #Cut the tree at constant height and show the clusters
+  cell.hclust(X,"f.tot.y",cutree="height",cutree.args=list(h=0.005))
 
+  #redefining the formula, plot against time in minutes
+  X<-transform(X,time.min=10+t.frame*15) #calculating the time of each t.frame
+  cell.hclust(X,"f.tot.y",formula=ucid~variable+time.min)
+}
 
 
 
@@ -260,29 +262,31 @@ nameEx("cimage")
 flush(stderr()); flush(stdout())
 
 ### Name: cimage
-### Title: Plot cell images
+### Title: Images Layout
 ### Aliases: cimage cimage.cell.image cimage.cell.data cimage.default
 ### Keywords: manip methods
 
 ### ** Examples
 
 
-#load example dataset
-data(ACL394filtered)
+if(interactive()&require(EBImage,quietly=TRUE)){
+	#load example dataset
+	data(ACL394filtered)
   
-#display timecourse strip of cell 5 of pos 29, channels BF and YFP
-if(interactive()) cimage(X,channel~t.frame,subset=pos==29&cellID==5,channel=c('BF','YFP'))
+	#display timecourse strip of cell 5 of pos 29, channels BF and YFP
+	cimage(X,channel~t.frame,subset=pos==29&cellID==5,channel=c('BF','YFP'))
 
-#display 7 cells (default value for N) of pos 29
-if(interactive()) cimage(X,...+channel~t.frame,subset=pos==29,channel=c('BF','YFP'))
+	#display 7 cells (default value for N) of pos 29
+	cimage(X,...+channel~t.frame,subset=pos==29,channel=c('BF','YFP'))
 
-#display 3 cells from each pos in a different facet
-if(interactive()) cimage(X,channel~...,facets=~pos,channel=c('BF.out','YFP'),N=3,
-    subset=t.frame==11&match(pos,c(1,8,15,22,29),nomatch=0)>0)
+	#display 3 cells from each pos in a different facet
+	cimage(X,channel~...,facets=~pos,channel=c('BF.out','YFP'),N=3,
+		subset=t.frame==11&match(pos,c(1,8,15,22,29),nomatch=0)>0)
 
-#select one BF and many YFP images
-if(interactive()) cimage(X,...~channel+t.frame,subset=pos==29,N=3,
-	channel.subset=channel=='YFP'|(channel=='BF.out'&t.frame==11))
+	#select one BF and many YFP images
+	cimage(X,...~channel+t.frame,subset=pos==29,N=3,
+		channel.subset=channel=='YFP'|(channel=='BF.out'&t.frame==11))
+}
 
 
 
@@ -295,8 +299,8 @@ flush(stderr()); flush(stdout())
 
 ### Name: cplot
 ### Title: Plotting Cell Data Objects
-### Aliases: cplot cplotmean cplotmeans clayer clayermean clayermeans
-###   plot.cell.data
+### Aliases: cplot cplotmean cplotmeans cplotmedian clayer clayermean
+###   clayermeans clayermedian plot.cell.data
 ### Keywords: hplot aplot
 
 ### ** Examples
@@ -334,16 +338,16 @@ cplot(X,f.tot.y~t.frame,facets=~AF.nM,size=0.5,geom="jitter")+
   clayermean(color="red")
 
 #plot means for each dose in the same plot
-cplotmean(X,f.tot.y~t.frame,color=AF.nM,as.factors="AF.nM",yzoom=c(0,6.2e6))
+cplotmean(X,f.tot.y~t.frame,color=AF.nM,as.factor="AF.nM",yzoom=c(0,6.2e6))
 
 #plotting histograms
 cplot(X,~f.tot.y)
 
 #map fill aesthetic to AF.nM variable coerced as factor
-cplot(X,~f.tot.y,fill=AF.nM,as.factors="AF.nM")
+cplot(X,~f.tot.y,fill=AF.nM,as.factor="AF.nM")
 
 #use position 'dodge' instead of 'stack'
-cplot(X,~f.tot.y,fill=AF.nM,as.factors="AF.nM",position="dodge")
+cplot(X,~f.tot.y,fill=AF.nM,as.factor="AF.nM",position="dodge")
 
 
 
@@ -364,25 +368,67 @@ flush(stderr()); flush(stdout())
 ### ** Examples
 
 
-#load example dataset
-data(ACL394filtered)
+if(interactive()&require(EBImage,quietly=TRUE)){
+  #load example dataset
+  data(ACL394filtered)
   
-#select N=3 cells images from each pos (group), 
-#from the first t.frame and pos 1,8,15,22,29.
-ci<-get.cell.image(X,subset=match(pos,c(1,8,15,22,29),nomatch=0)>0&t.frame==11,
-	group=.(pos),N=3,channel=c('BF.out','YFP'))
-if(interactive()) ci #print the cells images
-summary(ci) #get a summary of the content
-img.desc(ci) #get the image description data.frame
+  #select N=3 cells images from each pos (group), 
+  #from the first t.frame and pos 1,8,15,22,29.
+  ci<-get.cell.image(X,subset=match(pos,c(1,8,15,22,29),nomatch=0)>0&t.frame==11,
+    group=.(pos),N=3,channel=c('BF.out','YFP'))
+  print(ci) #print the cells images
+  summary(ci) #get a summary of the content
+  img.desc(ci) #get the image description data.frame
 
-#select the first 4 t.frames for YFP, and the first t.frame for BF
-ci<-get.cell.image(X,subset=pos==29,group='pos',
-	channel.subset=channel=='YFP'|(t.frame==11&channel=='BF'))
-if(interactive()) print(ci)
+  #select the first 4 t.frames for YFP, and the first t.frame for BF
+  ci<-get.cell.image(X,subset=pos==29,group='pos',
+    channel.subset=channel=='YFP'|(t.frame==11&channel=='BF'))
+  print(ci)
+}
 
 
 
 
+cleanEx()
+nameEx("ggplot2.themes")
+### * ggplot2.themes
+
+flush(stderr()); flush(stdout())
+
+### Name: ggplot2.themes
+### Title: ggplot2 themes
+### Aliases: ggplot2.themes ggplot2.theme ggplot.themes ggplot.theme
+###   theme_minimal theme_minimal_cb theme_minimal_cb_L theme_minimal_light
+###   theme_fullframe theme_black theme_complete_bw theme_invisible
+### Keywords: manip
+
+### ** Examples
+
+
+#themes for ggplot2 version 0.9.1 or lower
+if (as.numeric_version(utils::packageVersion("ggplot2"))< as.numeric_version("0.9.2")) {
+
+	#creating example datset
+	mdf <- data.frame(x <- seq(0, 10), y=rnorm(x), 
+                   f=factor(rep(letters[1:2], each=3, length=length(x))))
+	#base plot
+	p <- qplot(x, y, data=mdf, colour=f, geom=c("line", "point")) 
+
+	#compare themes
+	p + theme_grey() + opts(title="theme_grey()")
+	p + theme_bw() + opts(title="theme_bw()")
+	p + theme_minimal() + opts(title="theme_minimal()")
+	p + theme_minimal_cb() + opts(title="theme_minimal_cb()")
+	p + theme_minimal_cb_L() + opts(title="theme_minimal_cb_L()")
+	p + theme_minimal_light() + opts(title="theme_minimal_light()")
+	p + theme_fullframe() + opts(title="theme_fullframe()")
+	p + theme_black() + opts(title="theme_black()",plot.title = theme_text(colour = "white",size=14))
+	p + theme_complete_bw() + opts(title="theme_complete_bw()")
+	p + theme_invisible() + opts(title="theme_invisible()")
+}
+
+
+
 cleanEx()
 nameEx("load.cellID.data")
 ### * load.cellID.data
@@ -421,7 +467,7 @@ flush(stderr()); flush(stdout())
 data(ACL394)
 #creating data frame with information about each poistion
 #AF.nM: dose of alpha-factor yeast pheromone in nM
-pdata=data.frame(pos=1:35,AF.nM=rep(c(1.25,2.5,5,10,20),each=7))
+pdata<-data.frame(pos=1:35,AF.nM=rep(c(1.25,2.5,5,10,20),each=7))
 
 #merging the data frame with the cell.data object
 X<-merge(X,pdata)
@@ -455,6 +501,34 @@ print(cplot(X,f.tot.y~a.tot,color=pos), vp = vplayout(1, 2))
 
 
 
+cleanEx()
+nameEx("plot.Image")
+### * plot.Image
+
+flush(stderr()); flush(stdout())
+
+### Name: plot.Image
+### Title: Plot Image
+### Aliases: plot.Image
+### Keywords: manip methods
+
+### ** Examples
+
+
+if(interactive()&require(EBImage,quietly=TRUE)){
+
+  #load example dataset
+  data(ACL394filtered)
+  
+  #timecourse strip of cell 5 of pos 29, channels BF and YFP
+  img<-cimage(X,channel~t.frame,subset=pos==29&cellID==5,channel=c('BF','YFP'),display=FALSE)
+  plot(img)	
+
+}
+
+
+
+
 cleanEx()
 nameEx("reshape.cell.data")
 ### * reshape.cell.data
@@ -557,14 +631,124 @@ flush(stderr()); flush(stdout())
 ### ** Examples
 
 
-#load example dataset
-data(ACL394filtered)
+if(interactive()&require(EBImage,quietly=TRUE)){
+  #load example dataset
+  data(ACL394filtered)
   
-#display the BF out image from position 8 and t.frame 11
-if(interactive()) show.img(X,pos=8,t.frame=11)
+  #display the BF out image from position 8 and t.frame 11
+  show.img(X,pos=8,t.frame=11)
+
+  #display a stack of the YFP images of position 29
+  show.img(X,pos=29,t.frame=7:11,channel="YFP")
+}
+
+
+
+
+cleanEx()
+nameEx("stat_bootstrap")
+### * stat_bootstrap
+
+flush(stderr()); flush(stdout())
+
+### Name: stat_bootstrap
+### Title: Calculate bootstraps confidence intervals of a time course
+### Aliases: stat_bootstrap StatBootstrap
+
+### ** Examples
+
+
+#load example dataset
+data(ACL394)
+
+#plotting time courses for position 15
+cplot(X,f.tot.y~t.frame,subset=pos==15,geom="line",group=ucid)
+
+#using stat summary ignores the fact that the same cells are sampled at different times
+cplot(X,f.tot.y~t.frame,subset=pos==15,stat="summary",fun.data="mean_cl_boot"
+	,geom=c("point","errorbar","line"))
+
+#the stat bootstrap samples cells, and therefore the lack of independece is taken into account.
+#note that there can be no missing data for this to work. You can check this with the n.tot variable.
+X<-update_n.tot(X)
+cplot(X,f.tot.y~t.frame,subset=pos==15&n.tot==14,stat="bootstrap"
+	,geom=c("point","errorbar","line"),sample=ucid,group=pos)
+
+
+
+
+cleanEx()
+nameEx("stat_interactionError")
+### * stat_interactionError
+
+flush(stderr()); flush(stdout())
+
+### Name: stat_interactionError
+### Title: Calculate summary statistic after correcting for the 'sample
+###   effect'.
+### Aliases: stat_interactionError StatInteractionError
+
+### ** Examples
+
+
+#load example dataset
+data(ACL394)
+
+#plotting time courses for position 15
+cplot(X,f.tot.y~t.frame,subset=pos==15,geom="line",group=ucid)
+
+#using stat summary ignores the fact that the same cells are sampled at different times
+cplot(X,f.tot.y~t.frame,subset=pos==15,stat="summary",fun.data="mean_cl_normal"
+	,geom=c("point","errorbar","line"))
+
+#the interactioError stat eliminates the 'cell effect' before calculating the confidence
+#intervals. This works better if there are no missing values. Check for this with n.tot.
+X<-update_n.tot(X)
+cplot(X,f.tot.y~t.frame,subset=pos==15&n.tot==14
+	,stat="interactionError",fun.data="mean_cl_normal"
+	,geom=c("point","errorbar","line"),sample=ucid,group=pos)
+
+
+
+
+cleanEx()
+nameEx("stat_summaryGroup")
+### * stat_summaryGroup
+
+flush(stderr()); flush(stdout())
+
+### Name: stat_summaryGroup
+### Title: Summarise y and x values according to user defined groups.
+### Aliases: stat_summaryGroup StatSummaryGroup
+
+### ** Examples
+
+
+#load example dataset
+data(ACL394)
+
+#plotting all points of t.frame 12
+cplot(X,f.tot.y~f.tot.c,subset=t.frame==12)
+
+#using stat summary groups by x position, that makes no sense.
+cplot(X,f.tot.y~f.tot.c,subset=t.frame==12,stat="summary",fun.y=mean)
+
+#stat summaryGroup groups by pos in this example
+cplot(X,f.tot.y~f.tot.c,subset=t.frame==12,stat="summaryGroup",group=pos
+	,fun.y=mean,fun.x=mean)
+
+#errorbars can be added with the fun.ymin, fun.ymax, fun.xmin and fun.xmax arguments.
+cplot(X,f.tot.y~f.tot.c,subset=t.frame==12,stat="summaryGroup",group=pos
+	,geom=c("point","errorbar","errorbarh")
+	,fun.y=mean,fun.x=mean
+	,fun.ymax=function(x)mean(x)+sd(x),fun.ymin=function(x)mean(x)-sd(x)
+	,fun.xmax=function(x)mean(x)+sd(x),fun.xmin=function(x)mean(x)-sd(x))
+
+#use the fun.data for common summary functions
+cplot(X,f.tot.y~f.tot.c,subset=t.frame==12,stat="summaryGroup",group=pos
+	,geom=c("point","errorbar","errorbarh")
+	,fun.data="mean_cl_normal")
 
-#display a stack of the YFP images of position 29
-if(interactive()) show.img(X,pos=29,t.frame=7:11,channel="YFP")
 
 
 
@@ -634,7 +818,8 @@ flush(stderr()); flush(stdout())
 ### Name: transform
 ### Title: Transform a Cell Data Object
 ### Aliases: transform.cell.data transform.by transform.by.cell.data
-###   transform.by.data.frame transform.by.default
+###   transform.by.data.frame transform.by.default transformBy
+###   transformBy.cell.data transformBy.data.frame transformBy.default
 ### Keywords: manip methods
 
 ### ** Examples
@@ -646,10 +831,14 @@ data(ACL394filtered)
 X<-transform(X,f.total.y=f.tot.y-a.tot*f.local.bg.y)
 
 #create a new variable normalizing by position
-X<-transform.by(X,.(pos),norm.f.total.y=f.total.y/mean(f.total.y))
+X<-transformBy(X,.(pos),norm.f.total.y=f.total.y/mean(f.total.y))
 
 #create a new delta variable in sigle cells
-X<-transform.by(X,.(pos,cellID),delta.f.total.y=f.total.y-f.total.y[t.frame==0])
+X<-transformBy(X,.(pos,cellID),delta.f.total.y=f.total.y-f.total.y[t.frame==0])
+
+#transformBy can also be used on a data.frame
+df<-aggregate(X,f.total.y~t.frame+pos) #creates a aggregate data.frame from X
+df<-transformBy(df,.(pos),delta.f.total.y=f.total.y-f.total.y[t.frame==0])
 
 
 
@@ -662,42 +851,69 @@ flush(stderr()); flush(stdout())
 
 ### Name: transform.cell.image.rd
 ### Title: Transform Cell Image
-### Aliases: cnormalize
+### Aliases: cnormalize ciciply add.nucleus.boundary add.maj.min.axis
 ### Keywords: manip methods
 
 ### ** Examples
 
 
-#load example dataset
-data(ACL394)
+if(require(EBImage,quietly=TRUE)){ #suggested package EBImage required for these functions
+  #load example dataset
+  data(ACL394)
+
+  #select N=3 cells images from each pos (group), 
+  #from the first t.frame and pos 1,8,15,22,29.
+  ci<-get.cell.image(X,subset=match(pos,c(1,8,15,22,29),nomatch=0)>0&t.frame==11,
+  	group=.(pos),N=3,channel=c('BF','YFP'))
   
-#correcting the path to the images
-#normally you won't need to do this
-X$images$path<-factor(system.file('img', package='Rcell'))
-
-#select N=3 cells images from each pos (group), 
-#from the first t.frame and pos 1,8,15,22,29.
-ci<-get.cell.image(X,subset=match(pos,c(1,8,15,22,29),nomatch=0)>0&t.frame==11,
-	group=.(pos),N=3,channel=c('BF','YFP'))
-
-#display a cell image without normalization
-if(interactive()) display(tile(combine(ci))) 
-
-ci<-cnormalize(ci) #apply normalization
-if(interactive()) display(tile(combine(ci))) #display again
-
+  #display a cell image without normalization
+  if(interactive()) display(tile(combine(ci))) 
+  
+  ci<-cnormalize(ci) #apply normalization
+  if(interactive()) display(tile(combine(ci))) #display again
+}
 
 
 
 cleanEx()
-nameEx("update.n.tot")
-### * update.n.tot
+nameEx("update_img.path")
+### * update_img.path
 
 flush(stderr()); flush(stdout())
 
-### Name: update.n.tot
+### Name: update_img.path
+### Title: Update Image Path
+### Aliases: update_img.path
+### Keywords: manip
+
+### ** Examples
+
+## Not run: 
+##D #load example dataset 
+##D data(ACL394data)
+##D summary(X)
+##D 
+##D #the default path has to be updated
+##D new.path<-system.file('img', package='Rcell')
+##D X<-update_img.path(X,new.path)
+##D #a warning is issued because not all images were found
+##D #(not all images are included in the package to reduce the package size)
+##D 
+##D #cimage can now find the images
+##D cimage(X,channel~t.frame,subset=pos==29&cellID==5,channel=c('BF','YFP'))
+## End(Not run)
+
+
+
+cleanEx()
+nameEx("update_n.tot")
+### * update_n.tot
+
+flush(stderr()); flush(stdout())
+
+### Name: update_n.tot
 ### Title: Calculate Total Number of Frames for Each Cell
-### Aliases: update.n.tot
+### Aliases: update_n.tot update.n.tot
 ### Keywords: manip
 
 ### ** Examples
@@ -706,10 +922,10 @@ flush(stderr()); flush(stdout())
 data(ACL394)
 
 #update n.tot variable
-X<-update.n.tot(X)
+X<-update_n.tot(X)
 
 #this command is equivalent to
-X<-transform.by(X,.(ucid), n.tot=length(t.frame))
+X<-transformBy(X,.(ucid), n.tot=length(t.frame))
 
 
 
@@ -746,7 +962,7 @@ flush(stderr()); flush(stdout())
 
 ### Name: zoom
 ### Title: Zoom in a ggplot Object
-### Aliases: zoom xzoom yzoom
+### Aliases: zoom caxis xzoom yzoom
 ### Keywords: aplot
 
 ### ** Examples
@@ -757,6 +973,9 @@ data(ACL394)
 #zoom in the y axis
 cplotmeans(X,f.tot.y~t.frame,color=pos) + zoom(y=c(0,7e6))
 
+#define plotting region and ticks
+cplotmeans(X,f.tot.y~t.frame,color=pos) + caxis(y=c(0,7e6),x=c(0,13),nx=14,expand.x=c(-.75,.75))
+
 
 
 ### * <FOOTER>
